@@ -1,6 +1,6 @@
 # encoding=UTF-8
 
-# Copyright © 2010 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2010, 2011 Jakub Wilk <jwilk@jwilk.net>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -116,9 +116,9 @@ class Engine(common.Engine):
     def __init__(self, *args, **kwargs):
         assert args == ()
         common.Engine.__init__(self, *args, **kwargs)
-        self._check_version(self.executable)
+        self._check_version()
 
-    def _check_version(self, executable):
+    def _check_version(self):
         try:
             gocr = ipc.Subprocess([self.executable],
                 stdout=ipc.PIPE,
@@ -150,7 +150,7 @@ class Engine(common.Engine):
         yield _default_language
 
     @contextlib.contextmanager
-    def recognize(self, image, language, details=None):
+    def recognize(self, image, language, details=None, uax29=None):
         worker = ipc.Subprocess(
             [self.executable, '-i', image.name, '-f', 'XML'] + self.extra_args,
             stdout=ipc.PIPE,
